@@ -42,6 +42,7 @@
 
 #include <random>
 #include <QtWidgets>
+#include <QtGlobal>
 
 #include <xcb/xproto.h>
 #include <xcb/xcb_aux.h>
@@ -93,7 +94,7 @@ MpvProxy::MpvProxy(QWidget *parent)
             _gl_widget->setPlaying(state() != Backend::PlayState::Stopped);
             _gl_widget->update();
         });
-#ifdef USE_DXCB
+#if defined(USE_DXCB) || defined(_LIBDMR_)
         _gl_widget->toggleRoundedClip(false);
 #endif
 
@@ -111,6 +112,7 @@ MpvProxy::~MpvProxy()
     _connectStateChange = false;
     disconnect(window()->windowHandle(), &QWindow::windowStateChanged, 0, 0);
     if (CompositingManager::get().composited()) {
+        disconnect(this, &MpvProxy::stateChanged, 0, 0);
         delete _gl_widget;
     }
 }
@@ -142,7 +144,17 @@ mpv_handle* MpvProxy::mpv_init()
 
 #ifdef _LIBDMR_
     if (composited) {
-        set_property(h, "opengl-hwdec-interop", "vaapi-egl");
+        auto interop = QString::fromUtf8("vaapi-glx");
+        if (!qEnvironmentVariableIsEmpty("QT_XCB_GL_INTERGRATION")) {
+            auto gl_int = qgetenv("QT_XCB_GL_INTERGRATION");
+            if (gl_int == "xcb_egl") {
+                interop = "vaapi-egl";
+            } else {
+                interop = "vaapi-glx";
+            }
+        }
+        set_property(h, "opengl-hwdec-interop", interop.toUtf8().constData());
+        qDebug() << "set opengl-hwdec-interop = " << interop;
     }
     set_property(h, "hwdec", "auto");
 
@@ -742,7 +754,7 @@ void MpvProxy::play()
 
     qDebug () << args;
     command(_handle, args);
-    set_property(_handle, "pause", false);
+    set_property(_handle, "pause", _pauseOnStart);
 
 #ifndef _LIBDMR_
     // by giving a period of time, movie will be loaded and auto-loaded subs are 
@@ -1043,6 +1055,22 @@ void MpvProxy::updatePlayingMovieInfo()
     qDebug() << _pmf.audios;
 }
 
+void MpvProxy::nextFrame()
+{
+    if (state() == PlayState::Stopped) return;
+
+    QList<QVariant> args = { "frame-step"};
+    command(_handle, args);
+}
+
+void MpvProxy::previousFrame()
+{
+    if (state() == PlayState::Stopped) return;
+
+    QList<QVariant> args = { "frame-back-step"};
+    command(_handle, args);
+}
+
 QVariant MpvProxy::getProperty(const QString& name)
 {
     return get_property(_handle, name.toUtf8().data());
@@ -1050,7 +1078,11 @@ QVariant MpvProxy::getProperty(const QString& name)
 
 void MpvProxy::setProperty(const QString& name, const QVariant& val)
 {
-    set_property(_handle, name.toUtf8().data(), val);
+    if (name == "pause-on-start") {
+        _pauseOnStart = val.toBool();
+    } else {
+        set_property(_handle, name.toUtf8().data(), val);
+    }
 }
 
 } // end of namespace dmr
